@@ -32,7 +32,6 @@
 #include <QStandardPaths>
 
 #include <KPluginLoader>
-#include <KPluginMetaData>
 
 namespace Kerfuffle
 {
@@ -48,13 +47,36 @@ QMimeType determineMimeType(const QString& filename)
     // we cannot rely on it when the archive extension is wrong; we need to validate by hand.
     if (fileinfo.completeSuffix().toLower().remove(QRegularExpression(QStringLiteral("[^a-z\\.]"))).contains(QStringLiteral("tar."))) {
         inputFile.chop(fileinfo.completeSuffix().length());
+        QString cleanExtension(fileinfo.completeSuffix().toLower());
+
+        // tar.bz2 and tar.lz4 need special treatment since they contain numbers.
+        bool isBZ2 = false;
+        bool isLZ4 = false;
+        if (fileinfo.completeSuffix().toLower().contains(QStringLiteral("bz2"))) {
+            cleanExtension.remove(QStringLiteral("bz2"));
+            isBZ2 = true;
+        }
+        if (fileinfo.completeSuffix().toLower().contains(QStringLiteral("lz4"))) {
+            cleanExtension.remove(QStringLiteral("lz4"));
+            isLZ4 = true;
+        }
+
         // We remove non-alpha chars from the filename extension, but not periods.
         // If the filename is e.g. "foo.tar.gz.1", we get the "foo.tar.gz." string,
         // so we need to manually drop the last period character from it.
-        QString cleanExtension = fileinfo.completeSuffix().toLower().remove(QRegularExpression(QStringLiteral("[^a-z\\.]")));
+        cleanExtension.remove(QRegularExpression(QStringLiteral("[^a-z\\.]")));
         if (cleanExtension.endsWith(QLatin1Char('.'))) {
             cleanExtension.chop(1);
         }
+
+        // Re-add extension for tar.bz2 and tar.lz4.
+        if (isBZ2) {
+            cleanExtension.append(QStringLiteral(".bz2"));
+        }
+        if (isLZ4) {
+            cleanExtension.append(QStringLiteral(".lz4"));
+        }
+
         inputFile += cleanExtension;
         qCDebug(ARK) << "Validated filename of compressed tar" << filename << "into filename" << inputFile;
     }
@@ -70,7 +92,7 @@ QMimeType determineMimeType(const QString& filename)
 
     // Compressed tar-archives are detected as single compressed files when
     // detecting by content. The following code fixes detection of tar.gz, tar.bz2, tar.xz,
-    // tar.lzo and tar.lrz.
+    // tar.lzo, tar.lz and tar.lrz.
     if ((mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-compressed-tar")) &&
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/gzip"))) ||
         (mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-bzip-compressed-tar")) &&
@@ -81,8 +103,12 @@ QMimeType determineMimeType(const QString& filename)
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-compress"))) ||
         (mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-tzo")) &&
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-lzop"))) ||
+        (mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-lzip-compressed-tar")) &&
+         mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-lzip"))) ||
         (mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-lrzip-compressed-tar")) &&
-         mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-lrzip")))) {
+         mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-lrzip"))) ||
+        (mimeFromExtension == db.mimeTypeForName(QStringLiteral("application/x-lz4-compressed-tar")) &&
+         mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-lz4")))) {
         return mimeFromExtension;
     }
 
@@ -107,137 +133,4 @@ QMimeType determineMimeType(const QString& filename)
     return mimeFromContent;
 }
 
-QStringList supportedMimeTypes()
-{
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"), [](const KPluginMetaData& metaData) {
-        return metaData.serviceTypes().contains(QStringLiteral("Kerfuffle/Plugin"));
-    });
-
-    QSet<QString> supported;
-    foreach (const KPluginMetaData& pluginMetadata, offers) {
-
-        const QStringList executables = pluginMetadata.rawData()[QStringLiteral("X-KDE-Kerfuffle-ReadOnlyExecutables")].toString().split(QLatin1Char(';'));
-        if (!findExecutables(executables)) {
-            qCDebug(ARK) << "Could not find all the read-only executables of" << pluginMetadata.pluginId() << "- ignoring mimetypes:" << pluginMetadata.mimeTypes();
-            continue;
-        }
-
-        supported += pluginMetadata.mimeTypes().toSet();
-    }
-
-    // Remove entry for lrzipped tar if lrzip executable not found in path.
-    if (QStandardPaths::findExecutable(QStringLiteral("lrzip")).isEmpty()) {
-        supported.remove(QStringLiteral("application/x-lrzip-compressed-tar"));
-    }
-
-    qCDebug(ARK) << "Returning supported mimetypes" << supported;
-
-    return sortByComment(supported);
-}
-
-QSet<QString> supportedWriteMimeTypes()
-{
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"), [](const KPluginMetaData& metaData) {
-        return metaData.serviceTypes().contains(QStringLiteral("Kerfuffle/Plugin")) &&
-               metaData.rawData()[QStringLiteral("X-KDE-Kerfuffle-ReadWrite")].toVariant().toBool();
-    });
-
-    QSet<QString> supported;
-    foreach (const KPluginMetaData& pluginMetadata, offers) {
-
-        const QStringList executables = pluginMetadata.rawData()[QStringLiteral("X-KDE-Kerfuffle-ReadWriteExecutables")].toString().split(QLatin1Char(';'));
-        if (!findExecutables(executables)) {
-            qCDebug(ARK) << "Could not find all the read-write executables of" << pluginMetadata.pluginId() << "- ignoring mimetypes:" << pluginMetadata.mimeTypes();
-            continue;
-        }
-
-        supported += pluginMetadata.mimeTypes().toSet();
-    }
-
-    // Remove entry for lrzipped tar if lrzip executable not found in path.
-    if (QStandardPaths::findExecutable(QStringLiteral("lrzip")).isEmpty()) {
-        supported.remove(QStringLiteral("application/x-lrzip-compressed-tar"));
-    }
-
-    qCDebug(ARK) << "Returning supported write mimetypes" << supported;
-
-    return supported;
-}
-
-QSet<QString> supportedEncryptEntriesMimeTypes()
-{
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"), [](const KPluginMetaData& metaData) {
-        return metaData.serviceTypes().contains(QStringLiteral("Kerfuffle/Plugin"));
-    });
-
-    QSet<QString> supported;
-
-    foreach (const KPluginMetaData& pluginMetadata, offers) {
-        const QStringList mimeTypes = pluginMetadata.rawData()[QStringLiteral("X-KDE-Kerfuffle-EncryptEntries")].toString().split(QLatin1Char(','));
-        foreach (const QString& mimeType, mimeTypes) {
-            supported.insert(mimeType);
-        }
-    }
-
-    qCDebug(ARK) << "Entry encryption supported for mimetypes" << supported;
-
-    return supported;
-}
-
-QSet<QString> supportedEncryptHeaderMimeTypes()
-{
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"), [](const KPluginMetaData& metaData) {
-        return metaData.serviceTypes().contains(QStringLiteral("Kerfuffle/Plugin"));
-    });
-
-    QSet<QString> supported;
-
-    foreach (const KPluginMetaData& pluginMetadata, offers) {
-        const QStringList mimeTypes = pluginMetadata.rawData()[QStringLiteral("X-KDE-Kerfuffle-EncryptHeader")].toString().split(QLatin1Char(','));
-        foreach (const QString& mimeType, mimeTypes) {
-            supported.insert(mimeType);
-        }
-    }
-
-    qCDebug(ARK) << "Header encryption supported for mimetypes" << supported;
-
-    return supported;
-}
-
-QStringList sortByComment(const QSet<QString> &mimeTypeSet)
-{
-    QMap<QString,QString> map;
-
-    // Convert QStringList to QMap to sort by comment.
-    foreach (const QString &mimeType, mimeTypeSet) {
-        QMimeType mime(QMimeDatabase().mimeTypeForName(mimeType));
-        map[mime.comment().toLower()] = mime.name();
-    }
-
-    // Convert back to QStringList.
-    QStringList mimetypeList;
-    foreach (const QString &value, map) {
-        mimetypeList.append(value);
-    }
-
-    return mimetypeList;
-}
-
-bool findExecutables(const QStringList& executables)
-{
-    foreach (const QString& executable, executables) {
-
-        if (executable.isEmpty()) {
-            continue;
-        }
-
-        if (QStandardPaths::findExecutable(executable).isEmpty()) {
-            qCDebug(ARK) << "Could not find executable" << executable;
-            return false;
-        }
-    }
-
-    return true;
-}
-
 } // namespace Kerfuffle
